@@ -1,3 +1,4 @@
+
 use std::{fmt, str::FromStr};
 
 use serde::de::{self, Visitor};
@@ -29,10 +30,14 @@ pub mod date_time_format {
                     // Try both ways to parse the date.
                     match Utc.datetime_from_str(&s, FORMAT) {
                         Ok(r) => Ok(Some(r)),
-                        Err(_) => match Utc.datetime_from_str(&s, "%+") {
-                            Ok(d) => Ok(Some(d)),
-                            Err(e) => Err(serde::de::Error::custom(e.to_string())),
-                        },
+                        Err(_) => {
+                            match Utc.datetime_from_str(&s, "%+") {
+                                Ok(d) => Ok(Some(d)),
+                                Err(e) => {
+                                   Err(serde::de::Error::custom(e.to_string()))
+                                }
+                            }
+                        }
                     }
                 }
             }
@@ -453,4 +458,4 @@ pub fn zero_f32(num: &f32) -> bool {
 
 pub fn zero_f64(num: &f64) -> bool {
     *num == 0.0
-}
+}
\ No newline at end of file
